@@ -1,5 +1,6 @@
-#coding=utf8
+# coding: utf8
 
+from __future__ import unicode_literals
 from nltk.tag import stanford
 
 
@@ -12,16 +13,11 @@ class POSTagger(stanford.POSTagger):
 			kwargs['path_to_jar'] = 'resources/stanford-postagger.jar'
 		super(stanford.POSTagger, self).__init__(*args, **kwargs)
 
-	def batch_tag(self, sentences):
+	def tag_sents(self, sentences):
 		"""
 		>>> tagger.tag(['من', 'به', 'مدرسه', 'رفته بودم', '.'])
 		[('من', 'PR'), ('به', 'PREP'), ('مدرسه', 'N'), ('رفته بودم', 'V'), ('.', 'PUNC')]
 		"""
 		_sentences = [[item.replace(' ', '_') for item in sentence] for sentence in sentences]
-		results = super(stanford.POSTagger, self).batch_tag(_sentences)
+		results = super(stanford.POSTagger, self).tag_sents(_sentences)
 		return [[(word, tag[1].split('/')[-1]) for word, tag in zip(sentence, result)] for sentence, result in zip(sentences, results)]
-
-
-if __name__ == '__main__':
-	import doctest
-	doctest.testmod(extraglobs={'tagger': POSTagger()})
